@@ -15,7 +15,7 @@
 #' @param in_frame Frame variable. One dimensional object convertible to one-column \code{data.table} or variable name as character, column number.
 #' @param percentratio Positive numeric value. All linearized variables are multiplied with \code{percentratio} value, by default - 1.
 #' @param confidence optional; either a positive value for confidence interval. This variable by default is 0.95.
-#' 
+#' @param correction Logical value. If TRUE calculate variance without covariance (negative variance correction).
 #' 
 #' @return A list with objects are returned by the function:
 #'  \itemize{
@@ -52,7 +52,25 @@
 #'       \code{CI_lower} - the estimated confidence interval lower bound, \cr
 #'       \code{CI_upper} - the estimated confidence interval upper bound, \cr
 #'       \code{confidence_level} - the positive value for confidence interval, \cr 
-#'       \code{significant} - is the the difference significant
+#'       \code{significant} - is the the difference significant.
+#'   \item\code{annual_results_correction} - a \code{data.table} of corrected variables (if correction TRUE) containing:
+#'    \code{year_1} -  survey years of \code{years1} for measures of annual net change, \cr
+#'       \code{year_2} -  survey years of \code{years2} for measures of annual net change, \cr
+#'       \code{Dom} - optional variable of the population domains, \cr
+#'       \code{variable} - names of variables of interest, \cr
+#'       \code{estim_2} - the estimated value for period2 for measures of annual net change, \cr
+#'       \code{estim_1} - the estimated value for period1 for measures of annual net change, \cr
+#'       \code{estim} - the estimated value, \cr
+#'       \code{var} - the estimated variance, \cr
+#'       \code{se} - the estimated standard error, \cr
+#'       \code{rse} - the estimated relative standard error (coefficient of variation), \cr
+#'       \code{cv} - the estimated relative standard error (coefficient of variation) in percentage, \cr
+#'       \code{absolute_margin_of_error} - the estimated absolute margin of error for period1 for measures of annual, \cr
+#'       \code{relative_margin_of_error} - the estimated relative margin of error in percentage for measures of annual, \cr
+#'       \code{CI_lower} - the estimated confidence interval lower bound, \cr
+#'       \code{CI_upper} - the estimated confidence interval upper bound, \cr
+#'       \code{confidence_level} - the positive value for confidence interval, \cr 
+#'       \code{significant} - is the the difference significant.
 #'  }
 #'       
 #' @references
@@ -73,7 +91,7 @@ vardchangstrs <- function(Y, H, PSU, w_final,
                           dataset, periods1, periods2,
                           in_sample, in_frame,
                           confidence = 0.95,
-                          percentratio = 1){
+                          percentratio = 1, correction=FALSE){
 
 B_l <- Bl_sum <- CI_lower <- CI_upper <- D_l <- NULL
 Dl_sum <- P_hl <- ap_hl <- covv <- cv <- estim <- NULL
@@ -83,6 +101,7 @@ ind_2 <- kor <- n_q <- nh1 <- nh2 <- pop1 <- pop2 <- NULL
 pop_q <- rse <- rse2 <- sa1_hl <- sa1hl_sum <- NULL
 sa2_hl <- sa2hl_sum <- se <- sghl_sum <- type <- NULL
 var_1 <- var_2 <- variable_new <- NULL
+index_correct <- NULL
   
 dataset[, (periods) := lapply(.SD[, periods, with = FALSE], as.character)]
 calc <- vardom(Y = Y, H = H, PSU = PSU,
@@ -231,18 +250,45 @@ all_result[, estim := estim_2 / estim_1 * percentratio]
 all_result[, rse2 := var_1 / (estim_1) ^ 2 + var_2 / (estim_2) ^ 2 - 2 * covv / (estim_1 * estim_2)]
 all_result[, var := estim * rse2 * percentratio ^ 2]
 all_result[var >= 0, se := sqrt(var)]
-all_result[rse2 > 0, rse := sqrt(rse2)]
-all_result[, cv := 100 * rse]
 
-tsad <- qnorm(0.5 * (1 + confidence))
-all_result[, CI_lower := estim - tsad * se]
-all_result[, CI_upper := estim + tsad * se]
-
-sars <- c(Dom, "variable")
-all_result <- all_result[, c(paste0(periods, "_", 1:2), sars,
-                             paste0("estim_", 1:2), "estim",
-                             paste0("var_", 1:2), "covv", "var", "se",
-                             "cv", "CI_lower", "CI_upper"), with = FALSE]
-return(list(vardom_results = calc3,
-            all_result = all_result[]))
+if ( correction==FALSE){ 
+  all_result[rse2 > 0, rse := sqrt(rse2)]
+  all_result[, cv := 100 * rse]
+  tsad <- qnorm(0.5 * (1 + confidence))
+  all_result[, CI_lower := estim - tsad * se]
+  all_result[, CI_upper := estim + tsad * se]
+  
+  sars <- c(Dom, "variable")
+  all_result <- all_result[, c(paste0(periods, "_", 1:2), sars,
+                               paste0("estim_", 1:2), "estim",
+                               paste0("var_", 1:2), "covv", "var", "se",
+                               "cv", "CI_lower", "CI_upper"), with = FALSE]
+  return(list(vardom_results = calc3,
+              all_result = all_result[]))
+}else{ 
+  all_result[,index_correct:=ifelse(var<0,1,0)]#
+  all_result[rse2<0, rse2:=var_1 / (estim_1) ^ 2 + var_2 / (estim_2) ^ 2]#
+  all_result[rse2 > 0, rse := sqrt(rse2)]
+  
+  all_result[, var := estim * rse2 * percentratio ^ 2]#
+  all_result[var >= 0, se := sqrt(var)]#
+  all_result[, cv := 100 * rse]
+  
+  
+  
+  tsad <- qnorm(0.5 * (1 + confidence))
+  all_result[, CI_lower := estim - tsad * se]
+  all_result[, CI_upper := estim + tsad * se]
+  
+  sars <- c(Dom, "variable")
+  all_result <- all_result[, c(paste0(periods, "_", 1:2), sars,
+                               paste0("estim_", 1:2), "estim",
+                               paste0("var_", 1:2), "covv", "var", "se",
+                               "cv", "CI_lower", "CI_upper","index_correct"), with = FALSE]
+  correction <- all_result[index_correct==1]
+  all_result <- all_result[,-"index_correct"]
+  correction <- correction[,-"index_correct"]
+  return(list(vardom_results = calc3,
+              all_result = all_result[], correction= correction))
+  }
 }
